from asyncio import sleep as async_sleep
from threading import Thread


def sync_to_async(_func=None, rate=.001):
    def set_rate(func):
        async def wrapper(*args, **kwargs):
            th = Thread(target=func, args=args, kwargs=kwargs)
            th.start()
            while True:
                if not th.is_alive():
                    break
                await async_sleep(rate)

        return wrapper

    if _func is None:
        return set_rate
    return set_rate(_func)



from distutils.core import setup

setup(
    name='sync_to_async',
    packages=['sync_to_async'],
    version='0.1.1',
    license='MIT',
    description='Simple python decorator that will convert your sync function into async function',
    author='Menoua Esk',
    author_email='menooa2013@gmail.com',
    url='https://github.com/menooa25/sync_to_async/',
    download_url='https://github.com/menooa25/sync_to_async/archive/refs/heads/main.zip',
    keywords=['SYNC TO ASYNC', 'CONVERT SYNC TO ASYNC', 'CONVERT SYNC', 'CONVERT ASYNC', 'SYNC', 'ASYNC'],
    install_requires=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
    ],
)
